# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "accept_xff": "acceptXff",
    "activation_modes": "activationModes",
    "adaptive_limit": "adaptiveLimit",
    "advertize_route": "advertizeRoute",
    "allow_nat": "allowNat",
    "allow_snat": "allowSnat",
    "always_send": "alwaysSend",
    "app_service": "appService",
    "auth_passwordencrypted": "authPasswordencrypted",
    "auth_protocol": "authProtocol",
    "auto_delete": "autoDelete",
    "auto_sync": "autoSync",
    "basic_auth_realm": "basicAuthRealm",
    "client_profiles": "clientProfiles",
    "client_timeout": "clientTimeout",
    "close_wait_timeout": "closeWaitTimeout",
    "concurrent_streams_per_connection": "concurrentStreamsPerConnection",
    "configsync_ip": "configsyncIp",
    "conn_limit": "connLimit",
    "connection_idle_timeout": "connectionIdleTimeout",
    "connection_limit": "connectionLimit",
    "connpool_maxreuse": "connpoolMaxreuse",
    "connpool_maxsize": "connpoolMaxsize",
    "connpool_minsize": "connpoolMinsize",
    "connpool_replenish": "connpoolReplenish",
    "connpool_step": "connpoolStep",
    "connpoolidle_timeoutoverride": "connpoolidleTimeoutoverride",
    "content_type_excludes": "contentTypeExcludes",
    "content_type_includes": "contentTypeIncludes",
    "cookie_encryption": "cookieEncryption",
    "cookie_encryption_passphrase": "cookieEncryptionPassphrase",
    "cookie_name": "cookieName",
    "cpu_ratio": "cpuRatio",
    "default_persistence_profile": "defaultPersistenceProfile",
    "defaults_from": "defaultsFrom",
    "deferred_accept": "deferredAccept",
    "disk_ratio": "diskRatio",
    "dynamic_ratio": "dynamicRatio",
    "encrypt_cookie_secret": "encryptCookieSecret",
    "encrypt_cookies": "encryptCookies",
    "engine_id": "engineId",
    "execute_action": "executeAction",
    "explicitflow_migration": "explicitflowMigration",
    "fallback_host": "fallbackHost",
    "fallback_persistence_profile": "fallbackPersistenceProfile",
    "fallback_status_codes": "fallbackStatusCodes",
    "fast_open": "fastOpen",
    "finwait_timeout": "finwaitTimeout",
    "full_load_on_sync": "fullLoadOnSync",
    "full_path": "fullPath",
    "hardware_syncookie": "hardwareSyncookie",
    "hash_algorithm": "hashAlgorithm",
    "hash_length": "hashLength",
    "hash_offset": "hashOffset",
    "head_erase": "headErase",
    "head_insert": "headInsert",
    "header_table_size": "headerTableSize",
    "icmp_echo": "icmpEcho",
    "idle_timeout": "idleTimeout",
    "idle_timeout_override": "idleTimeoutOverride",
    "incremental_config": "incrementalConfig",
    "inherited_devicegroup": "inheritedDevicegroup",
    "inherited_traffic_group": "inheritedTrafficGroup",
    "insert_xforwarded_for": "insertXforwardedFor",
    "ip_dscp": "ipDscp",
    "ip_protocol": "ipProtocol",
    "iptos_toclient": "iptosToclient",
    "iptos_toserver": "iptosToserver",
    "keepalive_interval": "keepaliveInterval",
    "load_balancing_mode": "loadBalancingMode",
    "login_ref": "loginRef",
    "lws_separator": "lwsSeparator",
    "manual_resume": "manualResume",
    "map_proxies": "mapProxies",
    "match_across_pools": "matchAcrossPools",
    "match_across_services": "matchAcrossServices",
    "match_across_virtuals": "matchAcrossVirtuals",
    "max_age": "maxAge",
    "max_reuse": "maxReuse",
    "max_size": "maxSize",
    "maxheader_size": "maxheaderSize",
    "memory_ratio": "memoryRatio",
    "mirror_ip": "mirrorIp",
    "mirror_secondary_ip": "mirrorSecondaryIp",
    "name_servers": "nameServers",
    "network_failover": "networkFailover",
    "number_of_dots": "numberOfDots",
    "oneconnect_transformations": "oneconnectTransformations",
    "override_conn_limit": "overrideConnLimit",
    "persistence_profiles": "persistenceProfiles",
    "privacy_password": "privacyPassword",
    "privacy_password_encrypted": "privacyPasswordEncrypted",
    "privacy_protocol": "privacyProtocol",
    "proxy_type": "proxyType",
    "published_copy": "publishedCopy",
    "rate_limit": "rateLimit",
    "receive_disable": "receiveDisable",
    "redirect_rewrite": "redirectRewrite",
    "registration_key": "registrationKey",
    "request_chunking": "requestChunking",
    "reselect_tries": "reselectTries",
    "response_chunking": "responseChunking",
    "response_headers_permitteds": "responseHeadersPermitteds",
    "save_on_auto_sync": "saveOnAutoSync",
    "security_level": "securityLevel",
    "security_name": "securityName",
    "server_agent_name": "serverAgentName",
    "server_profiles": "serverProfiles",
    "service_down_action": "serviceDownAction",
    "share_pools": "sharePools",
    "slow_ramp_time": "slowRampTime",
    "source_address_translation": "sourceAddressTranslation",
    "source_mask": "sourceMask",
    "strict_updates": "strictUpdates",
    "sys_contact": "sysContact",
    "sys_location": "sysLocation",
    "template_modified": "templateModified",
    "template_prerequisite_errors": "templatePrerequisiteErrors",
    "time_until_up": "timeUntilUp",
    "tm_partition": "tmPartition",
    "token_auth": "tokenAuth",
    "traffic_group": "trafficGroup",
    "translate_address": "translateAddress",
    "translate_port": "translatePort",
    "uri_excludes": "uriExcludes",
    "uri_includes": "uriIncludes",
    "via_host_name": "viaHostName",
    "via_request": "viaRequest",
    "via_response": "viaResponse",
    "vlans_enabled": "vlansEnabled",
    "xff_alternative_names": "xffAlternativeNames",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "acceptXff": "accept_xff",
    "activationModes": "activation_modes",
    "adaptiveLimit": "adaptive_limit",
    "advertizeRoute": "advertize_route",
    "allowNat": "allow_nat",
    "allowSnat": "allow_snat",
    "alwaysSend": "always_send",
    "appService": "app_service",
    "authPasswordencrypted": "auth_passwordencrypted",
    "authProtocol": "auth_protocol",
    "autoDelete": "auto_delete",
    "autoSync": "auto_sync",
    "basicAuthRealm": "basic_auth_realm",
    "clientProfiles": "client_profiles",
    "clientTimeout": "client_timeout",
    "closeWaitTimeout": "close_wait_timeout",
    "concurrentStreamsPerConnection": "concurrent_streams_per_connection",
    "configsyncIp": "configsync_ip",
    "connLimit": "conn_limit",
    "connectionIdleTimeout": "connection_idle_timeout",
    "connectionLimit": "connection_limit",
    "connpoolMaxreuse": "connpool_maxreuse",
    "connpoolMaxsize": "connpool_maxsize",
    "connpoolMinsize": "connpool_minsize",
    "connpoolReplenish": "connpool_replenish",
    "connpoolStep": "connpool_step",
    "connpoolidleTimeoutoverride": "connpoolidle_timeoutoverride",
    "contentTypeExcludes": "content_type_excludes",
    "contentTypeIncludes": "content_type_includes",
    "cookieEncryption": "cookie_encryption",
    "cookieEncryptionPassphrase": "cookie_encryption_passphrase",
    "cookieName": "cookie_name",
    "cpuRatio": "cpu_ratio",
    "defaultPersistenceProfile": "default_persistence_profile",
    "defaultsFrom": "defaults_from",
    "deferredAccept": "deferred_accept",
    "diskRatio": "disk_ratio",
    "dynamicRatio": "dynamic_ratio",
    "encryptCookieSecret": "encrypt_cookie_secret",
    "encryptCookies": "encrypt_cookies",
    "engineId": "engine_id",
    "executeAction": "execute_action",
    "explicitflowMigration": "explicitflow_migration",
    "fallbackHost": "fallback_host",
    "fallbackPersistenceProfile": "fallback_persistence_profile",
    "fallbackStatusCodes": "fallback_status_codes",
    "fastOpen": "fast_open",
    "finwaitTimeout": "finwait_timeout",
    "fullLoadOnSync": "full_load_on_sync",
    "fullPath": "full_path",
    "hardwareSyncookie": "hardware_syncookie",
    "hashAlgorithm": "hash_algorithm",
    "hashLength": "hash_length",
    "hashOffset": "hash_offset",
    "headErase": "head_erase",
    "headInsert": "head_insert",
    "headerTableSize": "header_table_size",
    "icmpEcho": "icmp_echo",
    "idleTimeout": "idle_timeout",
    "idleTimeoutOverride": "idle_timeout_override",
    "incrementalConfig": "incremental_config",
    "inheritedDevicegroup": "inherited_devicegroup",
    "inheritedTrafficGroup": "inherited_traffic_group",
    "insertXforwardedFor": "insert_xforwarded_for",
    "ipDscp": "ip_dscp",
    "ipProtocol": "ip_protocol",
    "iptosToclient": "iptos_toclient",
    "iptosToserver": "iptos_toserver",
    "keepaliveInterval": "keepalive_interval",
    "loadBalancingMode": "load_balancing_mode",
    "loginRef": "login_ref",
    "lwsSeparator": "lws_separator",
    "manualResume": "manual_resume",
    "mapProxies": "map_proxies",
    "matchAcrossPools": "match_across_pools",
    "matchAcrossServices": "match_across_services",
    "matchAcrossVirtuals": "match_across_virtuals",
    "maxAge": "max_age",
    "maxReuse": "max_reuse",
    "maxSize": "max_size",
    "maxheaderSize": "maxheader_size",
    "memoryRatio": "memory_ratio",
    "mirrorIp": "mirror_ip",
    "mirrorSecondaryIp": "mirror_secondary_ip",
    "nameServers": "name_servers",
    "networkFailover": "network_failover",
    "numberOfDots": "number_of_dots",
    "oneconnectTransformations": "oneconnect_transformations",
    "overrideConnLimit": "override_conn_limit",
    "persistenceProfiles": "persistence_profiles",
    "privacyPassword": "privacy_password",
    "privacyPasswordEncrypted": "privacy_password_encrypted",
    "privacyProtocol": "privacy_protocol",
    "proxyType": "proxy_type",
    "publishedCopy": "published_copy",
    "rateLimit": "rate_limit",
    "receiveDisable": "receive_disable",
    "redirectRewrite": "redirect_rewrite",
    "registrationKey": "registration_key",
    "requestChunking": "request_chunking",
    "reselectTries": "reselect_tries",
    "responseChunking": "response_chunking",
    "responseHeadersPermitteds": "response_headers_permitteds",
    "saveOnAutoSync": "save_on_auto_sync",
    "securityLevel": "security_level",
    "securityName": "security_name",
    "serverAgentName": "server_agent_name",
    "serverProfiles": "server_profiles",
    "serviceDownAction": "service_down_action",
    "sharePools": "share_pools",
    "slowRampTime": "slow_ramp_time",
    "sourceAddressTranslation": "source_address_translation",
    "sourceMask": "source_mask",
    "strictUpdates": "strict_updates",
    "sysContact": "sys_contact",
    "sysLocation": "sys_location",
    "templateModified": "template_modified",
    "templatePrerequisiteErrors": "template_prerequisite_errors",
    "timeUntilUp": "time_until_up",
    "tmPartition": "tm_partition",
    "tokenAuth": "token_auth",
    "trafficGroup": "traffic_group",
    "translateAddress": "translate_address",
    "translatePort": "translate_port",
    "uriExcludes": "uri_excludes",
    "uriIncludes": "uri_includes",
    "viaHostName": "via_host_name",
    "viaRequest": "via_request",
    "viaResponse": "via_response",
    "vlansEnabled": "vlans_enabled",
    "xffAlternativeNames": "xff_alternative_names",
}
